@@ -40,7 +40,8 @@
 #define NAUTILUS_USER_DIRECTORY_NAME ".nautilus"
 #define DEFAULT_NAUTILUS_DIRECTORY_MODE (0755)
 
-#define DESKTOP_DIRECTORY_NAME ".gnome-desktop"
+#define DESKTOP_DIRECTORY_NAME "Desktop"
+#define LEGACY_DESKTOP_DIRECTORY_NAME ".gnome-desktop"
 #define DEFAULT_DESKTOP_DIRECTORY_MODE (0755)
 
 gboolean
@@ -59,43 +60,6 @@ nautilus_file_name_matches_backup_pattern (const char *name_or_relative_uri)
 	return eel_str_has_suffix (name_or_relative_uri, "~");
 }
 
-gboolean
-nautilus_file_name_matches_metafile_pattern (const char *name_or_relative_uri)
-{
-	g_return_val_if_fail (name_or_relative_uri != NULL, FALSE);
-
-	return eel_str_has_suffix (name_or_relative_uri, NAUTILUS_METAFILE_NAME_SUFFIX);
-}
-
-/**
- * nautilus_make_path:
- * 
- * Make a path name from a base path and name. The base path
- * can end with or without a separator character.
- *
- * Return value: the combined path name.
- **/
-char * 
-nautilus_make_path (const char *path, const char* name)
-{
-    	gboolean insert_separator;
-    	int path_length;
-	char *result;
-	
-	path_length = strlen (path);
-    	insert_separator = path_length > 0 && 
-    			   name[0] != '\0' && 
-    			   path[path_length - 1] != G_DIR_SEPARATOR;
-
-    	if (insert_separator) {
-    		result = g_strconcat (path, G_DIR_SEPARATOR_S, name, NULL);
-    	} else {
-    		result = g_strconcat (path, name, NULL);
-    	}
-
-	return result;
-}
-
 /**
  * nautilus_get_user_directory:
  * 
@@ -108,9 +72,10 @@ nautilus_get_user_directory (void)
 {
 	char *user_directory = NULL;
 
-	user_directory = nautilus_make_path (g_get_home_dir (),
-					     NAUTILUS_USER_DIRECTORY_NAME);
-
+	user_directory = g_build_filename (g_get_home_dir (),
+					   NAUTILUS_USER_DIRECTORY_NAME,
+					   NULL);
+	
 	if (!g_file_test (user_directory, G_FILE_TEST_EXISTS)) {
 		mkdir (user_directory, DEFAULT_NAUTILUS_DIRECTORY_MODE);
 		/* FIXME bugzilla.gnome.org 41286: 
@@ -125,6 +90,17 @@ nautilus_get_user_directory (void)
 	return user_directory;
 }
 
+static char *
+get_desktop_path (void)
+{
+	if (eel_preferences_get_boolean (NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR)) {
+		return g_strdup (g_get_home_dir());
+	} else {
+		return g_build_filename (g_get_home_dir (), DESKTOP_DIRECTORY_NAME, NULL);
+	}
+	
+}
+
 /**
  * nautilus_get_desktop_directory:
  * 
@@ -136,11 +112,11 @@ char *
 nautilus_get_desktop_directory (void)
 {
 	char *desktop_directory;
+	
+	desktop_directory = get_desktop_path ();
 
-	if (eel_preferences_get_boolean (NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR)) {
-		desktop_directory = g_strdup (g_get_home_dir());
-	} else {
-		desktop_directory = nautilus_get_gmc_desktop_directory ();
+	/* Don't try to create a home directory */
+	if (!eel_preferences_get_boolean (NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR)) {
 		if (!g_file_test (desktop_directory, G_FILE_TEST_EXISTS)) {
 			mkdir (desktop_directory, DEFAULT_DESKTOP_DIRECTORY_MODE);
 			/* FIXME bugzilla.gnome.org 41286: 
@@ -156,6 +132,85 @@ nautilus_get_desktop_directory (void)
 	return desktop_directory;
 }
 
+
+/**
+ * nautilus_get_desktop_directory_uri:
+ * 
+ * Get the uri for the directory containing files on the desktop.
+ *
+ * Return value: the directory path.
+ **/
+char *
+nautilus_get_desktop_directory_uri (void)
+{
+	char *desktop_path;
+	char *desktop_uri;
+	
+	desktop_path = nautilus_get_desktop_directory ();
+	desktop_uri = gnome_vfs_get_uri_from_local_path (desktop_path);
+	g_free (desktop_path);
+
+	return desktop_uri;
+}
+
+char *
+nautilus_get_desktop_directory_uri_no_create (void)
+{
+	char *desktop_path;
+	char *desktop_uri;
+	
+	desktop_path = get_desktop_path ();
+	desktop_uri = gnome_vfs_get_uri_from_local_path (desktop_path);
+	g_free (desktop_path);
+
+	return desktop_uri;
+}
+
+
+/* These need to be reset to NULL when desktop_is_home_dir changes */
+static char *escaped_desktop_dir = NULL;
+static char *escaped_desktop_file = NULL;
+static gboolean desktop_dir_changed_callback_installed = FALSE;
+
+static void
+desktop_dir_changed_callback (gpointer callback_data)
+{
+	g_free (escaped_desktop_dir);
+	g_free (escaped_desktop_file);
+	escaped_desktop_dir = NULL;
+	escaped_desktop_file = NULL;
+}
+
+gboolean
+nautilus_is_desktop_directory_escaped (char *escaped_dir,
+				       char *escaped_file)
+{
+	char *uri, *path;
+	GnomeVFSURI *vfs_uri;
+
+	if (!desktop_dir_changed_callback_installed) {
+		eel_preferences_add_callback (NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR,
+					      desktop_dir_changed_callback,
+					      NULL);
+		desktop_dir_changed_callback_installed = TRUE;
+	}
+		
+	if (escaped_desktop_dir == NULL) {
+		path = get_desktop_path ();
+		uri = gnome_vfs_get_uri_from_local_path (path);
+		vfs_uri = gnome_vfs_uri_new (uri);
+		g_free (path);
+		g_free (uri);
+		escaped_desktop_file = gnome_vfs_uri_extract_short_path_name (vfs_uri);
+		escaped_desktop_dir = gnome_vfs_uri_extract_dirname (vfs_uri);
+		gnome_vfs_uri_unref (vfs_uri);
+	}
+
+	return (strcmp (escaped_dir, escaped_desktop_dir) == 0 &&
+		strcmp (escaped_file, escaped_desktop_file) == 0);
+}
+
+
 /**
  * nautilus_get_gmc_desktop_directory:
  * 
@@ -166,7 +221,7 @@ nautilus_get_desktop_directory (void)
 char *
 nautilus_get_gmc_desktop_directory (void)
 {
-	return nautilus_make_path (g_get_home_dir (), DESKTOP_DIRECTORY_NAME);
+	return g_build_filename (g_get_home_dir (), LEGACY_DESKTOP_DIRECTORY_NAME, NULL);
 }
 
 /**
@@ -191,7 +246,7 @@ nautilus_pixmap_file (const char *partial_path)
 {
 	char *path;
 
-	path = nautilus_make_path (DATADIR "/pixmaps/nautilus", partial_path);
+	path = g_build_filename (DATADIR "/pixmaps/nautilus", partial_path, NULL);
 	if (g_file_test (path, G_FILE_TEST_EXISTS)) {
 		return path;
 	}
@@ -207,7 +262,7 @@ nautilus_get_data_file_path (const char *partial_path)
 
 	/* first try the user's home directory */
 	user_directory = nautilus_get_user_directory ();
-	path = nautilus_make_path (user_directory, partial_path);
+	path = g_build_filename (user_directory, partial_path, NULL);
 	g_free (user_directory);
 	if (g_file_test (path, G_FILE_TEST_EXISTS)) {
 		return path;
@@ -215,7 +270,7 @@ nautilus_get_data_file_path (const char *partial_path)
 	g_free (path);
 	
 	/* next try the shared directory */
-	path = nautilus_make_path (NAUTILUS_DATADIR, partial_path);
+	path = g_build_filename (NAUTILUS_DATADIR, partial_path, NULL);
 	if (g_file_test (path, G_FILE_TEST_EXISTS)) {
 		return path;
 	}
@@ -241,26 +296,6 @@ nautilus_unique_temporary_file_name (void)
 	return file_name;
 }
 
-char *
-nautilus_get_build_time_stamp (void)
-{
-#ifdef EAZEL_BUILD_TIMESTAMP
-	return g_strdup (EAZEL_BUILD_TIMESTAMP);
-#else
-	return NULL;
-#endif
-}
-
-char *
-nautilus_get_build_message (void)
-{
-#ifdef NAUTILUS_BUILD_MESSAGE
-	return g_strdup (NAUTILUS_BUILD_MESSAGE);
-#else
-	return NULL;
-#endif
-}
-
 #if !defined (NAUTILUS_OMIT_SELF_CHECK)
 
 void
